@@ -1,4 +1,4 @@
-//! Describes a FFI safe option.
+//! # FFI safe option.
 
 /// FFI-safe Option.
 ///
@@ -7,6 +7,7 @@
 ///
 /// Typical workflow would include temporarily converting into/from COption.
 #[repr(C)]
+#[cfg_attr(feature = "abi_stable", derive(::abi_stable::StableAbi))]
 pub enum COption<T> {
     None,
     Some(T),
